@@ -295,8 +295,6 @@ bool FrameBufferManager::IsDIaRenderTexture()
     bool foundFillRect=false;
     bool foundSetFillColor=false;
     bool foundSetCImg=false;
-    bool foundTxtRect=false;
-    int height;
     uint32 newFillColor = 0;
 
     uint32 dwPC = gDlistStack[gDlistStackPointer].pc;       // This points to the next instruction
@@ -308,14 +306,12 @@ bool FrameBufferManager::IsDIaRenderTexture()
 
         if( (w0>>24) == RDP_SETSCISSOR )
         {
-            height   = ((w1>>0 )&0xFFF)/4;
             foundSetScissor = true;
             continue;
         }
 
         if( (w0>>24) == RDP_SETFILLCOLOR )
         {
-            height   = ((w1>>0 )&0xFFF)/4;
             foundSetFillColor = true;
             newFillColor = w1;
             continue;
@@ -326,20 +322,17 @@ bool FrameBufferManager::IsDIaRenderTexture()
             uint32 x0   = ((w1>>12)&0xFFF)/4;
             uint32 y0   = ((w1>>0 )&0xFFF)/4;
             uint32 x1   = ((w0>>12)&0xFFF)/4;
-            uint32 y1   = ((w0>>0 )&0xFFF)/4;
 
             if( x0 == 0 && y0 == 0 )
             {
                 if( x1 == g_CI.dwWidth )
                 {
-                    height = y1;
                     foundFillRect = true;
                     continue;
                 }
 
                 if(x1 == (unsigned int)(g_CI.dwWidth-1))
                 {
-                    height = y1+1;
                     foundFillRect = true;
                     continue;
                 }
@@ -348,7 +341,6 @@ bool FrameBufferManager::IsDIaRenderTexture()
 
         if( (w0>>24) == RDP_TEXRECT )
         {
-            foundTxtRect = true;
             break;
         }
 
@@ -653,9 +645,9 @@ l1:             mov esi, [ecx+ebx]
             }
 #elif defined(__GNUC__) && defined(__x86_64__) && !defined(NO_ASM)
         asm volatile(" xorl          %k2,      %k2           \n"
-                     " movsxl        %k4,      %q4           \n"
+                     " movslq        %k4,      %q4           \n"
                      "0:                                     \n"
-                     " movsxl         %3,    %%rbx           \n"
+                     " movslq         %3,    %%rbx           \n"
                      " sub            $4,    %%rbx           \n"
                      "1:                                     \n"
                      " movl (%0,%%rbx,1),    %%eax           \n"
@@ -674,7 +666,7 @@ l1:             mov esi, [ecx+ebx]
                      : "%rbx", "%rax", "memory", "cc"
                      );
 #elif !defined(NO_ASM)
-# ifndef PIC
+# if !defined(__PIC__)
            asm volatile("pusha                             \n"
                 "mov    pAsmStart, %%ecx           \n"  // = pStart
                 "mov    $0, %%edx                  \n"          // The CRC
@@ -701,7 +693,7 @@ l1:             mov esi, [ecx+ebx]
                 :
                 : "memory", "cc"
                 );
-# else // PIC
+# else // defined(__PIC__)
            unsigned int saveEBX;
            unsigned int saveEAX;
            unsigned int saveECX;
@@ -747,7 +739,7 @@ l1:             mov esi, [ecx+ebx]
                 : "memory", "cc"
                 );
            dwAsmCRC = asmCRC;
-# endif // PIC
+# endif // defined(__PIC__)
 #endif
         }
         catch(...)
